import { InputLabel, MenuItem, Select } from '@mui/material';
import dynamic from 'next/dynamic'
import Image from 'next/image';
import React, { useState } from 'react'
import Modal from './model';
import { IMAGES, svgImages } from '@/utilities/utils';
import InputField from './InputField';
import { useSelector, useDispatch } from 'react-redux';
import { createAdmin } from '@/store/userReducer';
import Loader from '@/pages/Loader';
import { useTranslation } from 'react-i18next';
import ToggleLanguageButton from './ToggleLanguageButton';
import i18n from '../../i18n';


const FontIcon = dynamic(() => import('./FontIcon'), { ssr: false })


function CreateAdmin({ setCreateAdmin }) {
    const { t } = useTranslation()
    const { loader, adminData } = useSelector(state => state.user)
    const dispatch = useDispatch()
    const [deleteAdminModal, setDeleteAdminModal] = useState(false)
    const [errorForm, setErrorform] = useState(false)
    const [adminDetail, setAdminDetail] = useState({
        firstName: '',
        phoneNumber: {
            countryCode: "+972",
            number: ""
        },
        email: '',
        role: '',
    });

    const formConfig = [
        { key: 'firstName', label: 'Name', type: 'text' },
        { key: 'phoneNumber', label: 'Phone Number', type: 'text' },
        { key: 'email', label: 'Email', type: 'email' },
        {
            key: 'role',
            label: 'Superintendent Admin',
            type: 'select',
            options: ['admin', 'sub-admin'],
        },
    ];

    const handleChange = (e, key) => {
        if (key === 'phoneNumber') {
            setAdminDetail({
                ...adminDetail,
                phoneNumber: {
                    ...adminDetail.phoneNumber,
                    number: e.target.value,
                },
            });
        } else {
            setAdminDetail({
                ...adminDetail,
                [key]: e.target.value,
            });
        }
    };

    const isValidForm = () => {
        if (adminDetail?.firstName == '' || adminDetail?.phoneNumber?.number == '' || adminDetail?.email == '' || adminDetail?.role == '') {
            return false
        }
        return true
    }

    const handleSubmit = (e) => {
        e.preventDefault();
        if (isValidForm()) {
            dispatch(createAdmin({ data: adminDetail, token: adminData?.token, setCreateAdmin: () => setCreateAdmin(false), clearFields: () => clearFields(), alert: (msg) => alert(msg) }))
        } else {
            setErrorform(true)
        }
    };

    const handleDelete = () => {
        setDeleteAdminModal(false)
    }

    const clearFields = () => {
        setAdminDetail({
            name: '',
            phoneNumber: {
                countryCode: "+972",
                number: ""
            },
            email: '',
            role: '',
        })
    }




    return (
        <>
            {loader && <Loader />}
            <div className='flex flex-row items-center justify-between  mt-8 mx-12'>
                <h1 className={`${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}  text-[30px] select-none  `}>{t('createadmintxt')}</h1>
                <div className='flex gap-7'>
                    <FontIcon handleClick={() => clearFields()} size='xl' iconname="fa-solid fa-trash-can" className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen' />
                    <FontIcon handleClick={() => setCreateAdmin(false)} size='xl' iconname='fa-solid fa-xmark' className='text-appLightGrey rounded-full hover:cursor-pointer hover:text-appSeaGreen' />
                </div>
            </div>
            <form onSubmit={handleSubmit} className='flex flex-col items-center gap-10 justify-center mx-14 mt-[134px] '>
                <div className='flex w-full items-center justify-around'>
                    {formConfig.map((config) => {
                        return (
                            <div className='flex flex-col w-[22%] self-start' key={config.key}>
                                <InputLabel htmlFor={config.key}><p className={`font-normal text-[15px] ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} text-appBlack`}> {t(config.key)} </p></InputLabel>
                                {config.type === 'select' ? (
                                    <Select
                                        required={false}
                                        id={config.key}
                                        name={config.key}
                                        value={adminDetail[config.key]}
                                        onChange={(e) => handleChange(e, config.key)}
                                        className="mt-1  w-full rounded-md shadow-lg bg-gray-100 border-transparent  focus:border-appSeaGreen focus:bg-white focus:ring-0 h-[42px] items-center "
                                        displayEmpty
                                        sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }}
                                    >
                                        <MenuItem value="" disabled>
                                            {t('adminSelectoption')}
                                        </MenuItem>
                                        {config.options.map((option) => (
                                            <MenuItem sx={{ fontFamily: i18n.language == 'he' ? 'Rubik ,sans-serif' : 'Spartan , sans-serif' }} key={option} value={option}>
                                                {t(option)}
                                            </MenuItem>

                                        ))}
                                    </Select>
                                ) : (
                                    <InputField
                                        required={false}
                                        type={config.type}
                                        id={config.key}
                                        name={config.key}
                                        value={config.key == 'phoneNumber' ? adminDetail[config.key].number : adminDetail[config.key]}
                                        onChange={(e) => handleChange(e, config.key)}
                                    />
                                )}
                                {errorForm && <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'}  font-normal text-[11px] pt-1 ${adminDetail[config.key]?.number == '' || adminDetail[config.key] == '' ? 'visible' : 'invisible'}`}>{t('fillalert')}</p>}
                            </div>
                        )
                    })}
                </div>
                <div className='flex mb-10  mt-8 items-center justify-center'>
                    <button
                        type='submit'
                        className={`bg-transparent transition-all delay-100 hover:bg-appSeaGreen hover:text-appWhite w-[204px] h-[59px] text-appSeaGreen border-2 border-appSeaGreen  rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}   cursor-pointer `}
                    >
                        {t('createadmintxt')}
                    </button>
                </div>
            </form>
            <Modal isOpen={deleteAdminModal} onClose={setDeleteAdminModal}>
                <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 '>
                    <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
                </div>
                <Image onClick={() => { setDeleteAdminModal(false) }} className='mt-5 ml-3 hover:cursor-pointer' alt='backbtn' src={svgImages.modalbackbtn} />

                <div className='w-[430px]'>
                    <p className='text-appBlack font-spartan font-normal text-center text-[18px] mt-4'>
                        {t('deleteadminmodel')}
                    </p>
                </div>
                <div className='flex   mt-8 items-center justify-center'>
                    <button
                        onClick={() => handleDelete()}
                        className={`bg-transparent w-[134px] h-[59px] text-appRed border-2 border-appRed rounded-full text-center text-[22px] ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} cursor-pointer `}
                    >
                        Accept
                    </button>
                </div>
                <p className='text-appRed font-spartan font-normal text-[11px] w-[299px] mx-auto pt-[10px] pb-[19px]'>{t('deleteadminbelowwarning')}</p>
            </Modal>

        </>
    )
}

export default CreateAdmin